<?php
/**
 * Bulgarian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
 * @author Viktor Usunov <usun0v@mail.bg>
 * @author Kiril <neohidra@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Редактиране';
$lang['btn_source']            = 'Преглед на кода';
$lang['btn_show']              = 'Преглед на страницата';
$lang['btn_create']            = 'Създаване на страница';
$lang['btn_search']            = 'Търсене';
$lang['btn_save']              = 'Запис';
$lang['btn_preview']           = 'Преглед';
$lang['btn_top']               = 'Към началото';
$lang['btn_newer']             = '<< по-нови';
$lang['btn_older']             = 'по-стари >>';
$lang['btn_revs']              = 'История';
$lang['btn_recent']            = 'Скорошни промени';
$lang['btn_upload']            = 'Качване';
$lang['btn_cancel']            = 'Отказ';
$lang['btn_index']             = 'Индекс';
$lang['btn_secedit']           = 'Редактиране';
$lang['btn_login']             = 'Вписване';
$lang['btn_logout']            = 'Отписване';
$lang['btn_admin']             = 'Настройки';
$lang['btn_update']            = 'Актуализиране';
$lang['btn_delete']            = 'Изтриване';
$lang['btn_back']              = 'Назад';
$lang['btn_backlink']          = 'Обратни препратки';
$lang['btn_backtomedia']       = 'Назад към избора на файл';
$lang['btn_subscribe']         = 'Абонаменти';
$lang['btn_profile']           = 'Профил';
$lang['btn_reset']             = 'Изчистване';
$lang['btn_resendpwd']         = 'Пращане на нова парола';
$lang['btn_draft']             = 'Редактиране на чернова';
$lang['btn_recover']           = 'Възстановяване на чернова';
$lang['btn_draftdel']          = 'Изтриване на чернова';
$lang['btn_revert']            = 'Възстановяване';
$lang['btn_register']          = 'Регистриране';
$lang['btn_apply']             = 'Прилагане';
$lang['btn_media']             = 'Диспечер на файлове';
$lang['loggedinas']            = 'Вписани сте като';
$lang['user']                  = 'Потребител';
$lang['pass']                  = 'Парола';
$lang['newpass']               = 'Нова парола';
$lang['oldpass']               = 'Потвърждение на текуща парола';
$lang['passchk']               = 'още веднъж';
$lang['remember']              = 'Запомни ме';
$lang['fullname']              = 'Истинско име';
$lang['email']                 = 'Електронна поща';
$lang['profile']               = 'Потребителски профил';
$lang['badlogin']              = 'Грешно потребителско име или парола.';
$lang['minoredit']             = 'Незначителни промени';
$lang['draftdate']             = 'Черновата е автоматично записана на';
$lang['nosecedit']             = 'Страницата бе междувременно променена, презареждане на страницата поради неактуална информация.';
$lang['regmissing']            = 'Моля, попълнете всички полета.';
$lang['reguexists']            = 'Вече съществува потребител с избраното име.';
$lang['regsuccess']            = 'Потребителят е създаден, а паролата е пратена по електронната поща.';
$lang['regsuccess2']           = 'Потребителят е създаден.';
$lang['regmailfail']           = 'Изглежда, че има проблем с пращането на писмото с паролата. Моля, свържете се с администратора!';
$lang['regbadmail']            = 'Въведеният адрес изглежда невалиден - ако мислите, че това е грешка, свържете се с администратора.';
$lang['regbadpass']            = 'Двете въведени пароли не съвпадат, моля опитайте отново.';
$lang['regpwmail']             = 'Паролата ви за DokuWiki';
$lang['reghere']               = 'Все още нямате профил? Направете си';
$lang['profna']                = 'Wiki-то не поддържа промяна на профила';
$lang['profnochange']          = 'Няма промени.';
$lang['profnoempty']           = 'Въвеждането на име и ел. поща е задължително';
$lang['profchanged']           = 'Потребителският профил е обновен успешно.';
$lang['pwdforget']             = 'Забравили сте паролата си? Получете нова';
$lang['resendna']              = 'Wiki-то не поддържа повторно пращане на паролата.';
$lang['resendpwd']             = 'Изпращане на нова парола за';
$lang['resendpwdmissing']      = 'Моля, попълнете всички полета.';
$lang['resendpwdnouser']       = 'Потребителят не е намерен в базата от данни.';
$lang['resendpwdbadauth']      = 'Кодът за потвърждение е невалиден. Проверете дали сте използвали целия линк за потвърждение.';
$lang['resendpwdconfirm']      = 'Линк за потвърждение е пратен по електронната поща.';
$lang['resendpwdsuccess']      = 'Новата ви паролата е пратена по електронната поща.';
$lang['license']               = 'Ако не е посочено друго, съдържанието на Wiki-то е лицензирано под следния лиценз:';
$lang['licenseok']             = 'Бележка: Редактирайки страницата, вие се съгласявате да лицензирате промените (които сте направили) под следния лиценз:';
$lang['searchmedia']           = 'Търсене на файл: ';
$lang['searchmedia_in']        = 'Търсене в %s';
$lang['txt_upload']            = 'Изберете файл за качване';
$lang['txt_filename']          = 'Качи като (незадължително)';
$lang['txt_overwrt']           = 'Презапиши съществуващите файлове';
$lang['lockedby']              = 'В момента е заключена от';
$lang['lockexpire']            = 'Ще бъде отключена на';
$lang['js']['willexpire']      = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
$lang['js']['notsavedyet']     = 'Незаписаните промени ще бъдат загубени. Желаете ли да продължите?';
$lang['js']['searchmedia']     = 'Търсене на файлове';
$lang['js']['keepopen']        = 'Без затваряне на прозореца след избор';
$lang['js']['hidedetails']     = 'Без подробности';
$lang['js']['mediatitle']      = 'Настройки на препратката';
$lang['js']['mediadisplay']    = 'Тип на препратката';
$lang['js']['mediaalign']      = 'Подреждане';
$lang['js']['mediasize']       = 'Размер на изображението';
$lang['js']['mediatarget']     = 'Препращане към';
$lang['js']['mediaclose']      = 'Затваряне';
$lang['js']['mediainsert']     = 'Вмъкване';
$lang['js']['mediadisplayimg'] = 'Показвай изображението.';
$lang['js']['mediadisplaylnk'] = 'Показвай само препратката.';
$lang['js']['mediasmall']      = 'Малка версия';
$lang['js']['mediamedium']     = 'Средна версия';
$lang['js']['medialarge']      = 'Голяма версия';
$lang['js']['mediaoriginal']   = 'Оригинална версия';
$lang['js']['medialnk']        = 'Препратка към подробна страница';
$lang['js']['mediadirect']     = 'Директна препратка към оригинала';
$lang['js']['medianolnk']      = 'Без препратка';
$lang['js']['medianolink']     = 'Без препратка към изображението';
$lang['js']['medialeft']       = 'Подреди изображението отляво.';
$lang['js']['mediaright']      = 'Подреди изображението отдясно.';
$lang['js']['mediacenter']     = 'Подреди изображението по средата.';
$lang['js']['medianoalign']    = 'Без подреждане.';
$lang['js']['nosmblinks']      = 'Връзките към Windows shares работят само под Internet Explorer.
Можете да копирате и поставите връзката.';
$lang['js']['linkwiz']         = 'Помощник за препратки';
$lang['js']['linkto']          = 'Препратка към: ';
$lang['js']['del_confirm']     = 'Да бъдат ли изтрити избраните елементи?';
$lang['js']['restore_confirm'] = 'Наистина ли желаете да бъде възстановена тази версия?';
$lang['js']['media_diff']      = 'Преглед на разликите:';
$lang['js']['media_diff_both'] = 'Един до друг';
$lang['js']['media_diff_opacity'] = 'Наслагване (и прозиране)';
$lang['js']['media_diff_portions'] = 'По половинка';
$lang['js']['media_select']    = 'Изберете файлове...';
$lang['js']['media_upload_btn'] = 'Качване';
$lang['js']['media_done_btn']  = 'Готово';
$lang['js']['media_drop']      = 'Влачете и пуснете файливе тук, за да бъдат качени';
$lang['js']['media_cancel']    = 'премахване';
$lang['js']['media_overwrt']   = 'Презапиши съществуващите файлове';
$lang['rssfailed']             = 'Възникна грешка при получаването на емисията: ';
$lang['nothingfound']          = 'Нищо не е открито.';
$lang['mediaselect']           = 'Файлове';
$lang['fileupload']            = 'Качване на файлове';
$lang['uploadsucc']            = 'Качването е успешно';
$lang['uploadfail']            = 'Качването се провали. Може би поради грешни права?';
$lang['uploadwrong']           = 'Качването е отказано. Файлово разширение е забранено!';
$lang['uploadexist']           = 'Файлът вече съществува. Нищо не е направено.';
$lang['uploadbadcontent']      = 'Каченото съдържание не съответства на файлово разширение %s .';
$lang['uploadspam']            = 'Качването е блокирано от SPAM списъка.';
$lang['uploadxss']             = 'Качването е блокирано, поради възможно зловредно съдържание.';
$lang['uploadsize']            = 'Файлът за качване е прекалено голям. (макс. %s)';
$lang['deletesucc']            = 'Файлът "%s" бе изтрит.';
$lang['deletefail']            = '"%s" не може да бъде изтрит - проверете правата.';
$lang['mediainuse']            = 'Файлът "%s" не бе изтрит - все още се ползва.';
$lang['namespaces']            = 'Именни пространства';
$lang['mediafiles']            = 'Налични файлове в';
$lang['accessdenied']          = 'Нямате разрешение да преглеждате страницата.';
$lang['mediausage']            = 'Ползвайте следния синтаксис, за да упоменете файла:';
$lang['mediaview']             = 'Преглед на оригиналния файл';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Качете файл в текущото именно пространство. За създаване на подимено пространство, добавете име преди това на файла като ги разделите с двоеточие в полето "Качи като"';
$lang['mediaextchange']        = 'Разширението на файла е сменено от .%s на .%s!';
$lang['reference']             = 'Връзки за';
$lang['ref_inuse']             = 'Файлът не може да бъде изтрит, защото все още се ползва от следните страници:';
$lang['ref_hidden']            = 'Някои връзки са към страници, които нямате права да четете';
$lang['hits']                  = 'Съвпадения';
$lang['quickhits']             = 'Съвпадащи имена на страници';
$lang['toc']                   = 'Съдържание';
$lang['current']               = 'текуща';
$lang['yours']                 = 'Вашата версия';
$lang['diff']                  = 'Преглед на разликите с текущата версия';
$lang['diff2']                 = 'Показване на разликите между избрани версии';
$lang['difflink']              = 'Препратка към сравнението на версиите';
$lang['diff_type']             = 'Преглед на разликите:';
$lang['diff_inline']           = 'Вграден';
$lang['diff_side']             = 'Един до друг';
$lang['line']                  = 'Ред';
$lang['breadcrumb']            = 'Следа';
$lang['youarehere']            = 'Намирате се в';
$lang['lastmod']               = 'Последна промяна';
$lang['by']                    = 'от';
$lang['deleted']               = 'изтрита';
$lang['created']               = 'създадена';
$lang['restored']              = 'възстановена предишна версия';
$lang['external_edit']         = 'външна редакция';
$lang['summary']               = 'Обобщение';
$lang['noflash']               = 'Необходим е <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> за изобразяване на съдържанието.';
$lang['download']              = 'Изтегляне на фрагмент';
$lang['mail_newpage']          = 'добавена страница: ';
$lang['mail_changed']          = 'променена страница: ';
$lang['mail_subscribe_list']   = 'променени страници в именно пространство: ';
$lang['mail_new_user']         = 'нов потребител: ';
$lang['mail_upload']           = 'качен файл: ';
$lang['changes_type']          = 'Преглед на променените';
$lang['pages_changes']         = 'Страници';
$lang['media_changes']         = 'Файлове';
$lang['both_changes']          = 'Страници и файлове';
$lang['qb_bold']               = 'Удебелен текст';
$lang['qb_italic']             = 'Курсив текст';
$lang['qb_underl']             = 'Подчертан текст';
$lang['qb_code']               = 'Код';
$lang['qb_strike']             = 'Зачеркнат текст';
$lang['qb_h1']                 = 'Заглавие от 1 ниво';
$lang['qb_h2']                 = 'Заглавие от 2 ниво';
$lang['qb_h3']                 = 'Заглавие от 3 ниво';
$lang['qb_h4']                 = 'Заглавие от 4 ниво';
$lang['qb_h5']                 = 'Заглавие от 5 ниво';
$lang['qb_h']                  = 'Заглавие';
$lang['qb_hs']                 = 'Изберете заглавие';
$lang['qb_hplus']              = 'Надзаглавие';
$lang['qb_hminus']             = 'Подзаглавие';
$lang['qb_hequal']             = 'Заглавие от същото ниво';
$lang['qb_link']               = 'Вътрешна препратка';
$lang['qb_extlink']            = 'Външна препратка';
$lang['qb_hr']                 = 'Хоризонтална линия';
$lang['qb_ol']                 = 'Номериран списък';
$lang['qb_ul']                 = 'Неномериран списък';
$lang['qb_media']              = 'Добавяне на изображения и други файлове';
$lang['qb_sig']                = 'Вмъкване на подпис';
$lang['qb_smileys']            = 'Усмивчици';
$lang['qb_chars']              = 'Специални знаци';
$lang['upperns']               = 'към майчиното именно пространство';
$lang['admin_register']        = 'Добавяне на нов потребител';
$lang['metaedit']              = 'Редактиране на метаданни';
$lang['metasaveerr']           = 'Записването на метаданните се провали';
$lang['metasaveok']            = 'Метаданните са запазени успешно';
$lang['img_backto']            = 'Назад към';
$lang['img_title']             = 'Заглавие';
$lang['img_caption']           = 'Надпис';
$lang['img_date']              = 'Дата';
$lang['img_fname']             = 'Име на файла';
$lang['img_fsize']             = 'Размер';
$lang['img_artist']            = 'Фотограф';
$lang['img_copyr']             = 'Авторско право';
$lang['img_format']            = 'Формат';
$lang['img_camera']            = 'Фотоапарат';
$lang['img_keywords']          = 'Ключови думи';
$lang['img_width']             = 'Ширина';
$lang['img_height']            = 'Височина';
$lang['img_manager']           = 'Преглед в диспечера на файлове';
$lang['subscr_subscribe_success'] = '%s е добавен към списъка с абониралите се за %s';
$lang['subscr_subscribe_error'] = 'Грешка при добавянето на %s към списъка с абониралите се за %s';
$lang['subscr_subscribe_noaddress'] = 'Добавянето ви към списъка с абонати не е възможно поради липсата на свързан адрес (на ел. поща) с профила ви.';
$lang['subscr_unsubscribe_success'] = '%s е премахнат от списъка с абониралите се за %s';
$lang['subscr_unsubscribe_error'] = 'Грешка при премахването на %s от списъка с абониралите се за %s';
$lang['subscr_already_subscribed'] = '%s е вече абониран за %s';
$lang['subscr_not_subscribed'] = '%s не е абониран за %s';
$lang['subscr_m_not_subscribed'] = 'Не сте абониран за текущата страницата или именно пространство.';
$lang['subscr_m_new_header']   = 'Добави абонамент';
$lang['subscr_m_current_header'] = 'Текущи абонаменти';
$lang['subscr_m_unsubscribe']  = 'Прекратяване на абонамента';
$lang['subscr_m_subscribe']    = 'Абониране';
$lang['subscr_m_receive']      = 'Получаване';
$lang['subscr_style_every']    = 'на ел. писмо при всяка промяна';
$lang['subscr_style_digest']   = 'на ел. писмо с обобщение на промените във всяка страница (всеки %.2f дни)';
$lang['subscr_style_list']     = 'на списък с променените страници от последното ел. писмо (всеки %.2f дни)';
$lang['authmodfailed']         = 'Лоша настройки за удостоверяване. Моля, уведомете администратора на Wiki страницата.';
$lang['authtempfail']          = 'Удостоверяването на потребители не е възможно за момента. Ако продължи дълго, моля уведомете администратора на Wiki страницата.';
$lang['i_chooselang']          = 'Изберете вашия изик';
$lang['i_installer']           = 'Инсталатор на DokuWiki';
$lang['i_wikiname']            = 'Име на Wiki-то';
$lang['i_enableacl']           = 'Ползване на списък за достъп (ACL) [препоръчително]';
$lang['i_superuser']           = 'Супер потребител';
$lang['i_problems']            = 'Открити са проблеми, които възпрепятстват инсталирането. Ще можете да продължите след като отстраните долуизброените проблеми.';
$lang['i_modified']            = 'Поради мерки за сигурност инсталаторът работи само с нови и непроменени инсталационни файлове. Трябва да разархивирате отново файловете от сваления архив или да се посъветвате с <a href="http://dokuwiki.org/install">Инструкциите за инсталиране на Dokuwiki</a>.';
$lang['i_funcna']              = 'PHP функцията <code>%s</code> не е достъпна. Може би е забранена от доставчика на хостинг.';
$lang['i_phpver']              = 'Инсталираната версия <code>%s</code> на PHP е по-стара от необходимата <code>%s</code>. Актуализирайте PHP инсталацията.';
$lang['i_permfail']            = '<code>%s</code> не е достъпна за писане от DokuWiki. Трябва да промените правата за достъп до директорията!';
$lang['i_confexists']          = '<code>%s</code> вече съществува';
$lang['i_writeerr']            = '<code>%s</code> не можа да бъде създаден. Трябва да проверите правата за достъп до директорията/файла и да създадете файла ръчно.';
$lang['i_badhash']             = 'Файлът dokuwiki.php не може да бъде разпознат или е променен (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - непозволена или празна стойност';
$lang['i_success']             = 'Настройването приключи успешно. Вече можете да изтриете файла install.php. Продължете към <a href="doku.php">Вашето ново DokuWiki</a>.';
$lang['i_failure']             = 'Възникнаха грешки при записването на файловете с настройки. Вероятно ще се наложи да ги поправите ръчно, за да можете да ползвате <a href="doku.php">Вашето ново DokuWiki</a>.';
$lang['i_policy']              = 'Първоначална политика за достъп';
$lang['i_pol0']                = 'Отворено Wiki (всеки може да чете, пише и качва)';
$lang['i_pol1']                = 'Публично Wiki (всеки може да чете, само регистрирани пишат и качват)';
$lang['i_pol2']                = 'Затворено Wiki (само регистрирани четат, пишат и качват)';
$lang['i_retry']               = 'Повторен опит';
$lang['i_license']             = 'Моля, изберете лиценз под който желаете да публикувате съдържанието:';
$lang['recent_global']         = 'В момента преглеждате промените в именно пространство <b>%s</b>. Може да прегледате и <a href="%s">промените в цялото Wiki</a>.';
$lang['years']                 = 'преди %d години';
$lang['months']                = 'преди %d месеца';
$lang['weeks']                 = 'преди %d седмици';
$lang['days']                  = 'преди %d дни';
$lang['hours']                 = 'преди %d часа';
$lang['minutes']               = 'преди %d минути';
$lang['seconds']               = 'преди %d секунди';
$lang['wordblock']             = 'Направените от вас промени не са съхранени, защото съдържат забранен текст (SPAM).';
$lang['media_uploadtab']       = 'Качване';
$lang['media_searchtab']       = 'Търсене';
$lang['media_file']            = 'Файл';
$lang['media_viewtab']         = 'Преглед';
$lang['media_edittab']         = 'Редактиране';
$lang['media_historytab']      = 'История';
$lang['media_list_thumbs']     = 'Миниатюри';
$lang['media_list_rows']       = 'Редове';
$lang['media_sort_name']       = 'Име';
$lang['media_sort_date']       = 'Дата';
$lang['media_namespaces']      = 'Изберете:';
$lang['media_files']           = 'Файлове в %s';
$lang['media_upload']          = 'Качване в %s';
$lang['media_search']          = 'Търсене в %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s в %s';
$lang['media_edit']            = 'Редактиране на %s';
$lang['media_history']         = 'История на %s';
$lang['media_meta_edited']     = 'редактиране на метаданните';
$lang['media_perm_read']       = 'За съжаление нямате достатъчно права, за да можете да прочетете файла.';
$lang['media_perm_upload']     = 'За съжаление нямате достатъчно права, за да можете да качите файла.';
$lang['media_update']          = 'Качване на нова версия';
$lang['media_restore']         = 'Възстановяване на тази версия';
$lang['plugin_install_err']    = 'Неправилно инсталирана приставка. Моля, преименувайте директорията \'%s\' на \'%s\'.';
